@@ -1272,10 +1272,13 @@ class QuipGlobalConfig:
                 self.conf["new"] = True
 
     def find_config_path(self, config_path=None):
-        home_folder = os.path.expanduser("~")
-        config_file = config_file_home = os.path.join(home_folder, ".uip_config.yml")
-        if not os.path.exists(config_file):
-            config_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", ".uip_config.yml")
+        current_folder = os.path.curdir
+        config_file = config_file_home = os.path.join(current_folder, ".uip_config.yml")
+        if os.path.exists(config_file):
+            logging.warning(f"Project specific config file found.")
+        else:
+            home_folder = os.path.expanduser("~")
+            config_file = config_file_home = os.path.join(home_folder, ".uip_config.yml")
         
         if os.path.exists(config_file):
             logging.info(f"Using config from file : {config_file}")
@@ -1286,25 +1289,6 @@ class QuipGlobalConfig:
             self.new_config = True
             return config_file
     
-    def yes_or_no(self, question, default=None):
-        if default == True:
-            options = "(Y/n)"
-        elif default == False:
-            options = "(y/N)"
-        else:
-            options = "(y/n)"
-            default = None
-
-        while True:
-            answer = input(question + options + ": ").lower().strip()
-            
-            if len(answer) == 0 and default is not None:
-                return default
-            elif answer[0] in  ["y", "yes"]:
-                return True
-            elif answer[0] in  ["n", "no"]:
-                return False
-    
     def setup_config(self, config_file):
         logging.info("You don't have any config file. I think this is the first time you are running this tool.")
         if yes_or_no(f"Do you want to download sample quip config? (Destination: {config_file}): ", default=True):
@@ -1319,8 +1303,8 @@ class QuipGlobalConfig:
             
             logging.info(f"Config file created. Check {config_file}")
             cprint("You need to pull the baseline projects. Use the following command.", color="cyan")
-            cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ue-baseline.git", color="cyan")
-            cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ut-baseline.git", color="cyan")
+            cprint("git clone https://gitlab.stonebranch.com/cs-uac/ue-baseline.git", color="cyan")
+            cprint("git clone https://gitlab.stonebranch.com/cs-uac/ut-baseline.git", color="cyan")
             
             self.check_config(conf)
 
